@@ -31,12 +31,14 @@
 #' need to be elements of \code{stringi::stri_trans_list()} (like "Latin-ASCII", which is often useful) or names of lookup tables (currently
 #' only "german" is supported). In the order of the entries the letters of the input
 #'  string will be transliterated via \code{stringi::stri_trans_general()} or replaced via the 
-#'  matches of the lookup table.
-#'  
+#'  matches of the lookup table. When named character elements are supplied as part of `transliterations`, anything that matches the names is replaced by the corresponding value.
+
 #' You should use this feature with care in case of \code{case = "parsed"}, \code{case = "internal_parsing"} and 
 #' \code{case = "none"}, since for upper case letters, which have transliterations/replacements
 #'  of length 2, the second letter will be transliterated to lowercase, for example Oe, Ae, Ss, which
-#'  might not always be what is intended.
+#'  might not always be what is intended. In this case you can make usage of the option to supply named elements and specify the transliterations yourself.
+#' 
+#' @param numerals A character specifying the alignment of numerals (\code{"middle"}, \code{left}, \code{right} or \code{asis}). I.e. \code{numerals = "left"} ensures that no output separator is in front of a digit.
 #' 
 #' @param sep_out (short for separator output) String that will be used as separator. The defaults are \code{"_"} 
 #' and \code{""}, regarding the specified \code{case}.
@@ -78,6 +80,7 @@
 #' to_parsed_case(strings)
 #' to_mixed_case(strings)
 #' to_swap_case(strings)
+#' to_sentence_case(strings)
 #' 
 #' 
 #' @rdname caseconverter
@@ -89,6 +92,7 @@ to_snake_case <- function(string,
                           sep_in = "[^[:alnum:]]",
                           parsing_option = 1,
                           transliterations = NULL,
+                          numerals = "middle",
                           sep_out = NULL,
                           unique_sep = NULL,
                           empty_fill = NULL,
@@ -97,7 +101,8 @@ to_snake_case <- function(string,
   to_any_case(string = string,
               case = "snake",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,     
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -114,7 +119,8 @@ to_lower_camel_case <- function(string,
                                 abbreviations = NULL,
                                 sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
-                                transliterations = NULL, 
+                                transliterations = NULL,   
+                                numerals = "middle", 
                                 sep_out = NULL,
                                 unique_sep = NULL,
                                 empty_fill = NULL,
@@ -123,7 +129,8 @@ to_lower_camel_case <- function(string,
   to_any_case(string = string,
               case = "lower_camel",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,               
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -140,7 +147,7 @@ to_upper_camel_case <- function(string,
                                 abbreviations = NULL,
                                 sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
-                                transliterations = NULL,
+                                transliterations = NULL,                           numerals = "middle",                                  
                                 sep_out = NULL,
                                 unique_sep = NULL,
                                 empty_fill = NULL,
@@ -149,7 +156,8 @@ to_upper_camel_case <- function(string,
   to_any_case(string = string,
               case = "upper_camel",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,               
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -166,7 +174,7 @@ to_screaming_snake_case <- function(string,
                                     abbreviations = NULL,
                                     sep_in = "[^[:alnum:]]",
                                     parsing_option = 1,
-                                    transliterations = NULL,
+                                    transliterations = NULL,                           numerals = "middle",                                  
                                     sep_out = NULL,
                                     unique_sep = NULL,
                                     empty_fill = NULL,
@@ -175,7 +183,8 @@ to_screaming_snake_case <- function(string,
   to_any_case(string = string,
               case = "screaming_snake",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,               
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -192,7 +201,7 @@ to_parsed_case <- function(string,
                            abbreviations = NULL,
                            sep_in = "[^[:alnum:]]",
                            parsing_option = 1,
-                           transliterations = NULL,
+                           transliterations = NULL,                           numerals = "middle",                                  
                            sep_out = NULL,
                            unique_sep = NULL,
                            empty_fill = NULL,
@@ -201,7 +210,8 @@ to_parsed_case <- function(string,
   to_any_case(string = string,
               case = "parsed",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,               
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -218,7 +228,8 @@ to_mixed_case <- function(string,
                           abbreviations = NULL,
                           sep_in = "[^[:alnum:]]",
                           parsing_option = 1,
-                          transliterations = NULL,
+                          transliterations = NULL,               
+                          numerals = "middle",   
                           sep_out = NULL,
                           unique_sep = NULL,
                           empty_fill = NULL,
@@ -227,7 +238,8 @@ to_mixed_case <- function(string,
   to_any_case(string = string,
               case = "mixed",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,               
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -244,7 +256,8 @@ to_lower_upper_case <- function(string,
                                 abbreviations = NULL,
                                 sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
-                                transliterations = NULL,
+                                transliterations = NULL,        
+                                numerals = "middle",   
                                 sep_out = NULL,
                                 unique_sep = NULL,
                                 empty_fill = NULL,
@@ -253,7 +266,8 @@ to_lower_upper_case <- function(string,
   to_any_case(string = string,
               case = "lower_upper",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,  
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -270,7 +284,8 @@ to_upper_lower_case <- function(string,
                                 abbreviations = NULL,
                                 sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
-                                transliterations = NULL,
+                                transliterations = NULL,  
+                                numerals = "middle",  
                                 sep_out = NULL,
                                 unique_sep = NULL,
                                 empty_fill = NULL,
@@ -279,7 +294,8 @@ to_upper_lower_case <- function(string,
   to_any_case(string = string,
               case = "upper_lower",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,            
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
@@ -293,19 +309,48 @@ to_upper_lower_case <- function(string,
 #' @export
 
 to_swap_case <- function(string,
-                                abbreviations = NULL,
-                                sep_in = "[^[:alnum:]]",
-                                parsing_option = 1,
-                                transliterations = NULL,
-                                sep_out = NULL,
-                                unique_sep = NULL,
-                                empty_fill = NULL,
-                                prefix = "",
-                                postfix = ""){
+                         abbreviations = NULL,
+                         sep_in = "[^[:alnum:]]",
+                         parsing_option = 1,
+                         transliterations = NULL,             
+                         numerals = "middle",                   
+                         sep_out = NULL,
+                         unique_sep = NULL,
+                         empty_fill = NULL,
+                         prefix = "",
+                         postfix = ""){
   to_any_case(string = string,
               case = "swap",
               sep_in = sep_in,
-              transliterations = transliterations,
+              transliterations = transliterations,              
+              numerals = numerals,
+              sep_out = sep_out,
+              prefix = prefix,
+              postfix = postfix,
+              unique_sep = unique_sep,
+              empty_fill = empty_fill,
+              parsing_option = parsing_option,
+              abbreviations = abbreviations)
+}
+
+#' @rdname caseconverter
+#' @export
+
+to_sentence_case <- function(string,
+                         abbreviations = NULL,
+                         sep_in = "[^[:alnum:]]",
+                         parsing_option = 1,
+                         transliterations = NULL,       
+                         numerals = "middle",                                             sep_out = NULL,
+                         unique_sep = NULL,
+                         empty_fill = NULL,
+                         prefix = "",
+                         postfix = ""){
+  to_any_case(string = string,
+              case = "sentence",
+              sep_in = sep_in,
+              transliterations = transliterations,  
+              numerals = numerals,
               sep_out = sep_out,
               prefix = prefix,
               postfix = postfix,
